[evolution-data-server] M!84 - Correct typos of doesnt/dont



commit e071a0aafc8b8d214e8b437a86b748fd385f3534
Author: Дилян Палаузов <git-dpa aegee org>
Date:   Tue Jul 13 12:41:18 2021 +0300

    M!84 - Correct typos of doesnt/dont
    
    Closes https://gitlab.gnome.org/GNOME/evolution-data-server/-/merge_requests/84

 src/addressbook/libedata-book/e-book-sqlite.c                    | 4 ++--
 src/calendar/libedata-cal/e-cal-backend-sexp.c                   | 4 ++--
 src/camel/camel-charset-map.c                                    | 2 +-
 src/camel/camel-folder-search.c                                  | 2 +-
 src/camel/camel-folder-summary.c                                 | 4 ++--
 src/camel/camel-folder-thread.c                                  | 2 +-
 src/camel/camel-folder.c                                         | 6 +++---
 src/camel/camel-html-parser.c                                    | 2 +-
 src/camel/camel-iconv.c                                          | 2 +-
 src/camel/camel-mime-filter.c                                    | 2 +-
 src/camel/camel-mime-message.c                                   | 4 ++--
 src/camel/camel-mime-parser.c                                    | 6 +++---
 src/camel/camel-mime-part.c                                      | 2 +-
 src/camel/camel-mime-utils.c                                     | 4 ++--
 src/camel/camel-movemail.c                                       | 2 +-
 src/camel/camel-multipart-signed.h                               | 2 +-
 src/camel/camel-net-utils.c                                      | 2 +-
 src/camel/camel-sexp.c                                           | 2 +-
 src/camel/camel-text-index.c                                     | 2 +-
 src/camel/camel-vee-store.c                                      | 2 +-
 src/camel/camel-win32.h                                          | 2 +-
 src/camel/providers/imapx/camel-imapx-command.c                  | 2 +-
 src/camel/providers/imapx/camel-imapx-server.c                   | 2 +-
 src/camel/providers/imapx/camel-imapx-utils.c                    | 8 ++++----
 src/camel/providers/local/camel-local-folder.c                   | 2 +-
 src/camel/providers/local/camel-local-private.h                  | 2 +-
 src/camel/providers/local/camel-local-summary.c                  | 4 ++--
 src/camel/providers/local/camel-maildir-summary.c                | 8 ++++----
 src/camel/providers/local/camel-mbox-folder.c                    | 4 ++--
 src/camel/providers/local/camel-mbox-summary.c                   | 2 +-
 src/camel/providers/local/camel-mh-store.c                       | 2 +-
 src/camel/providers/local/camel-spool-summary.c                  | 2 +-
 src/camel/providers/nntp/camel-nntp-private.h                    | 2 +-
 src/camel/providers/nntp/camel-nntp-store.c                      | 2 +-
 src/camel/providers/pop3/camel-pop3-engine.h                     | 4 ++--
 src/camel/providers/pop3/camel-pop3-folder.c                     | 4 ++--
 src/camel/providers/pop3/camel-pop3-store.c                      | 6 +++---
 src/camel/tests/lib/folders.c                                    | 2 +-
 src/camel/tests/message/test2.c                                  | 2 +-
 src/examples/cursor/cursor-data.c                                | 2 +-
 src/libedataserver/e-sexp.c                                      | 2 +-
 src/private/org.gnome.evolution.dataserver.AddressBookCursor.xml | 2 +-
 tests/libebook/client/test-book-client-cursor-operations.c       | 2 +-
 tests/libedataserver/e-collator-test.c                           | 2 +-
 44 files changed, 65 insertions(+), 65 deletions(-)
---
diff --git a/src/addressbook/libedata-book/e-book-sqlite.c b/src/addressbook/libedata-book/e-book-sqlite.c
index 093790615..ee4d4e032 100644
--- a/src/addressbook/libedata-book/e-book-sqlite.c
+++ b/src/addressbook/libedata-book/e-book-sqlite.c
@@ -1023,8 +1023,8 @@ ebsql_string_append_vprintf (GString *string,
 {
        gchar *stmt;
 
-       /* Unfortunately, sqlite3_vsnprintf() doesnt tell us
-        * how many bytes it would have needed if it doesnt fit
+       /* Unfortunately, sqlite3_vsnprintf() doesn't tell us
+        * how many bytes it would have needed if it doesn't fit
         * into the target buffer, so we can't avoid this
         * really disgusting memory dup.
         */
diff --git a/src/calendar/libedata-cal/e-cal-backend-sexp.c b/src/calendar/libedata-cal/e-cal-backend-sexp.c
index 07e342f7f..6881c2d10 100644
--- a/src/calendar/libedata-cal/e-cal-backend-sexp.c
+++ b/src/calendar/libedata-cal/e-cal-backend-sexp.c
@@ -863,7 +863,7 @@ func_has_duration (ESExp *esexp,
 
 /* (has-alarms?)
  *
- * A boolean value for components that have/dont have alarms.
+ * A boolean value for components that have/don't have alarms.
  *
  * Returns: a boolean indicating whether the component has alarms or not.
  */
@@ -1072,7 +1072,7 @@ func_has_categories (ESExp *esexp,
 
 /* (has-recurrences?)
  *
- * A boolean value for components that have/dont have recurrences.
+ * A boolean value for components that have/don't have recurrences.
  *
  * Returns: a boolean indicating whether the component has recurrences or not.
  */
diff --git a/src/camel/camel-charset-map.c b/src/camel/camel-charset-map.c
index c886eeaa8..c1a0292d8 100644
--- a/src/camel/camel-charset-map.c
+++ b/src/camel/camel-charset-map.c
@@ -133,7 +133,7 @@ gint main (gint argc, gchar **argv)
        gint bytes;
        GIConv cd;
 
-       /* dont count the terminator */
+       /* don't count the terminator */
        bytes = (G_N_ELEMENTS (tables) + 7 - 1) / 8;
        g_return_val_if_fail (bytes <= 4, -1);
 
diff --git a/src/camel/camel-folder-search.c b/src/camel/camel-folder-search.c
index f865c690c..319166651 100644
--- a/src/camel/camel-folder-search.c
+++ b/src/camel/camel-folder-search.c
@@ -596,7 +596,7 @@ match_words_1message (CamelDataWrapper *object,
                /* for messages we only look at its contents */
                truth = match_words_1message ((CamelDataWrapper *) containee, words, mask, cancellable);
        } else if (camel_content_type_is (camel_data_wrapper_get_mime_type_field (CAMEL_DATA_WRAPPER 
(containee)), "text", "*")) {
-               /* for all other text parts, we look inside, otherwise we dont care */
+               /* for all other text parts, we look inside, otherwise we don't care */
                CamelStream *stream;
                GByteArray *byte_array;
                const gchar *charset;
diff --git a/src/camel/camel-folder-thread.c b/src/camel/camel-folder-thread.c
index 088b1d91b..b20319c1f 100644
--- a/src/camel/camel-folder-thread.c
+++ b/src/camel/camel-folder-thread.c
@@ -927,7 +927,7 @@ camel_folder_thread_messages_add (CamelFolderThread *thread,
        for (i = 0; i < summary->len; i++) {
                CamelMessageInfo *info = summary->pdata[i];
 
-               /* check its not already there, we dont want duplicates */
+               /* check it is not already there, we don't want duplicates */
                if (g_hash_table_lookup (table, camel_message_info_get_uid (info)) == NULL)
                        g_ptr_array_add (all, info);
        }
diff --git a/src/camel/camel-folder.c b/src/camel/camel-folder.c
index 48c3a3f6e..f28b0300c 100644
--- a/src/camel/camel-folder.c
+++ b/src/camel/camel-folder.c
@@ -4938,7 +4938,7 @@ change_info_remove (gchar *key,
                return;
        }
 
-       /* we dont need to copy this, as they've already been copied into our pool */
+       /* we don't need to copy this, as they've already been copied into our pool */
        g_ptr_array_add (info->uid_removed, key);
        g_hash_table_insert (p->uid_stored, key, info->uid_removed);
 }
@@ -4976,7 +4976,7 @@ change_info_recent_uid (CamelFolderChangeInfo *info,
 
        p = info->priv;
 
-       /* always add to recent, but dont let anyone else know */
+       /* always add to recent, but don't let anyone else know */
        if (!g_hash_table_lookup_extended (p->uid_stored, uid, (gpointer *) &olduid, (gpointer *) &olduids)) {
                olduid = camel_mempool_strdup (p->uid_pool, uid);
        }
@@ -4993,7 +4993,7 @@ change_info_filter_uid (CamelFolderChangeInfo *info,
 
        p = info->priv;
 
-       /* always add to filter, but dont let anyone else know */
+       /* always add to filter, but don't let anyone else know */
        if (!g_hash_table_lookup_extended (p->uid_stored, uid, (gpointer *) &olduid, (gpointer *) &olduids)) {
                olduid = camel_mempool_strdup (p->uid_pool, uid);
        }
diff --git a/src/camel/camel-html-parser.c b/src/camel/camel-html-parser.c
index 5a83b7f04..27f87a057 100644
--- a/src/camel/camel-html-parser.c
+++ b/src/camel/camel-html-parser.c
@@ -633,7 +633,7 @@ static gint tokenize_step (CamelHTMLParserPrivate *p, gchar **datap, gint *lenp)
                                *lenp = in-start-1;
                                goto done;
                        } else if (c == '-') {
-                               /* we dont care if we get 'n' --'s before the > */
+                               /* we don't care if we get 'n' --'s before the > */
                                if (p->tag->len < 2)
                                        g_string_append_c (p->tag, c);
                        } else {
diff --git a/src/camel/camel-iconv.c b/src/camel/camel-iconv.c
index 723707fda..50625f920 100644
--- a/src/camel/camel-iconv.c
+++ b/src/camel/camel-iconv.c
@@ -502,7 +502,7 @@ camel_iconv_close (GIConv ip)
                in->busy = FALSE;
                g_queue_push_tail (&in->parent->open, in);
        } else {
-               g_warning ("trying to close iconv i dont know about: %p", ip);
+               g_warning ("trying to close iconv I don't know about: %p", ip);
                g_iconv_close (ip);
        }
        G_UNLOCK (iconv);
diff --git a/src/camel/camel-mime-filter.c b/src/camel/camel-mime-filter.c
index fa9aa7e44..52ad506b2 100644
--- a/src/camel/camel-mime-filter.c
+++ b/src/camel/camel-mime-filter.c
@@ -159,7 +159,7 @@ filter_run (CamelMimeFilter *f,
 
                newlen = len + prespace + f->backlen;
                if (p->inlen < newlen) {
-                       /* NOTE: g_realloc copies data, we dont need that (slower) */
+                       /* NOTE: g_realloc copies data, we don't need that (slower) */
                        g_free (p->inbuf);
                        p->inbuf = g_malloc (newlen + PRE_HEAD);
                        p->inlen = newlen + PRE_HEAD;
diff --git a/src/camel/camel-mime-message.c b/src/camel/camel-mime-message.c
index ae951bb7c..216b2054d 100644
--- a/src/camel/camel-mime-message.c
+++ b/src/camel/camel-mime-message.c
@@ -84,7 +84,7 @@ typedef enum {
 } CamelHeaderType;
 
 static const gchar *header_names[] = {
-       /* dont include HEADER_UNKNOWN string */
+       /* don't include HEADER_UNKNOWN string */
        "From", "Reply-To", "Subject", "To", "Resent-To", "Cc", "Resent-Cc",
        "Bcc", "Resent-Bcc", "Date", "Message-ID", NULL
 };
@@ -1046,7 +1046,7 @@ find_best_encoding (CamelMimePart *part,
                charset = NULL;
        }
 
-       /* if we have US-ASCII, or we're not doing text, we dont need to bother with the rest */
+       /* if we have US-ASCII, or we're not doing text, we don't need to bother with the rest */
        if (istext && charsetin && charset && (required & CAMEL_BESTENC_GET_CHARSET) != 0) {
                d (printf ("have charset, trying conversion/etc\n"));
 
diff --git a/src/camel/camel-mime-parser.c b/src/camel/camel-mime-parser.c
index 00d6c6d26..8c4ec7696 100644
--- a/src/camel/camel-mime-parser.c
+++ b/src/camel/camel-mime-parser.c
@@ -89,7 +89,7 @@ struct _header_scan_state {
        /* for scanning input buffers */
        gchar *realbuf;         /* the real buffer, SCAN_HEAD *2 + SCAN_BUF bytes */
        gchar *inbuf;           /* points to a subset of the allocated memory, the underflow */
-       gchar *inptr;           /* (upto SCAN_HEAD) is for use by filters so they dont copy all data */
+       gchar *inptr;           /* (upto SCAN_HEAD) is for use by filters so they don't copy all data */
        gchar *inend;
 
        gint atleast;
@@ -130,7 +130,7 @@ struct _header_scan_stack {
 
        CamelContentType *content_type;
 
-       /* I dont use GString's casue you can't efficiently append a buffer to them */
+       /* I don't use GString's casue you can't efficiently append a buffer to them */
        GByteArray *pretext;    /* for multipart types, save the pre-boundary data here */
        GByteArray *posttext;   /* for multipart types, save the post-boundary data here */
        gint prestage;          /* used to determine if it is a pre-boundary or post-boundary data segment */
@@ -1170,7 +1170,7 @@ folder_boundary_check (struct _header_scan_state *s,
                        gint *lastone)
 {
        struct _header_scan_stack *part;
-       gint len = s->inend - boundary; /* make sure we dont access past the buffer */
+       gint len = s->inend - boundary; /* make sure we don't access past the buffer */
 
        h (printf ("checking boundary marker upto %d bytes\n", len));
        part = s->parts;
diff --git a/src/camel/camel-mime-part.c b/src/camel/camel-mime-part.c
index ac915040f..e6c5229f7 100644
--- a/src/camel/camel-mime-part.c
+++ b/src/camel/camel-mime-part.c
@@ -1446,7 +1446,7 @@ camel_mime_part_set_disposition (CamelMimePart *mime_part,
 
        medium = CAMEL_MEDIUM (mime_part);
 
-       /* we poke in a new disposition (so we dont lose 'filename', etc) */
+       /* we poke in a new disposition (so we don't lose 'filename', etc) */
        if (mime_part->priv->disposition == NULL)
                mime_part_set_disposition (mime_part, disposition);
 
diff --git a/src/camel/camel-mime-utils.c b/src/camel/camel-mime-utils.c
index 761811bb1..02d487363 100644
--- a/src/camel/camel-mime-utils.c
+++ b/src/camel/camel-mime-utils.c
@@ -2693,10 +2693,10 @@ header_decode_mailbox (const gchar **in,
                                gsize l = strlen (last);
                                gsize p = strlen (pre);
 
-                               /* dont append ' ' between sucsessive encoded words */
+                               /* don't append ' ' between sucsessive encoded words */
                                if ((l > 6 && last[l - 2] == '?' && last[l - 1] == '=')
                                    && (p > 6 && pre[0] == '=' && pre[1] == '?')) {
-                                       /* dont append ' ' */
+                                       /* don't append ' ' */
                                } else {
                                        g_string_append_c (name, ' ');
                                }
diff --git a/src/camel/camel-movemail.c b/src/camel/camel-movemail.c
index 3bda65328..4e47dd806 100644
--- a/src/camel/camel-movemail.c
+++ b/src/camel/camel-movemail.c
@@ -427,7 +427,7 @@ camel_movemail_copy_filter (gint fromfd,
        return written;
 }
 
-/* write the headers back out again, but not he Content-Length header, because we dont
+/* write the headers back out again, but not the Content-Length header, because we don't
  * want        to maintain it! */
 static gint
 solaris_header_write (gint fd,
diff --git a/src/camel/camel-multipart-signed.h b/src/camel/camel-multipart-signed.h
index aef7d5fbe..f61402959 100644
--- a/src/camel/camel-multipart-signed.h
+++ b/src/camel/camel-multipart-signed.h
@@ -19,7 +19,7 @@
  */
 
 /* Should this be a subclass of multipart?
- * No, because we dont have different parts?
+ * No, because we don't have different parts?
  * I'm not really sure yet ... ? */
 
 #if !defined (__CAMEL_H_INSIDE__) && !defined (CAMEL_COMPILATION)
diff --git a/src/camel/camel-net-utils.c b/src/camel/camel-net-utils.c
index ef37877f1..9a259050d 100644
--- a/src/camel/camel-net-utils.c
+++ b/src/camel/camel-net-utils.c
@@ -569,7 +569,7 @@ cs_getaddrinfo (gpointer data)
                msg->hostbufmem = g_realloc (msg->hostbufmem, msg->hostbuflen);
        }
 
-       /* If we got cancelled, dont reply, just free it */
+       /* If we got cancelled, don't reply, just free it */
        if (msg->cancelled)
                goto cancel;
 
diff --git a/src/camel/camel-sexp.c b/src/camel/camel-sexp.c
index f1617ad7c..c59bc41eb 100644
--- a/src/camel/camel-sexp.c
+++ b/src/camel/camel-sexp.c
@@ -101,7 +101,7 @@ struct _CamelSExpPrivate {
        GSList *operators;
 
        /* TODO: may also need a pool allocator for term strings,
-        *       so we dont lose them in error conditions? */
+        *       so we don't lose them in error conditions? */
        CamelMemChunk *term_chunks;
        CamelMemChunk *result_chunks;
 };
diff --git a/src/camel/camel-text-index.c b/src/camel/camel-text-index.c
index 7187646d8..2afef6e78 100644
--- a/src/camel/camel-text-index.c
+++ b/src/camel/camel-text-index.c
@@ -311,7 +311,7 @@ text_index_sync (CamelIndex *idx)
 
        CAMEL_TEXT_INDEX_LOCK (idx, lock);
 
-       /* we sync, bump down the cache limits since we dont need them for reading */
+       /* we sync, bump down the cache limits since we don't need them for reading */
        camel_block_file_set_cache_limit (p->blocks, 128);
        /* this doesn't really need to be dropped, its only used in updates anyway */
        p->word_cache_limit = 1024;
diff --git a/src/camel/camel-vee-store.c b/src/camel/camel-vee-store.c
index 09bac5e4e..3723dd965 100644
--- a/src/camel/camel-vee-store.c
+++ b/src/camel/camel-vee-store.c
@@ -568,7 +568,7 @@ camel_vee_store_init (CamelVeeStore *vee_store)
        vee_store->priv->vee_data_cache = camel_vee_data_cache_new ();
        vee_store->priv->unmatched_enabled = TRUE;
 
-       /* we dont want a vtrash/vjunk on this one */
+       /* we don't want a vtrash/vjunk on this one */
        camel_store_set_flags (store, camel_store_get_flags (store) & ~(CAMEL_STORE_VTRASH | 
CAMEL_STORE_VJUNK));
 }
 
diff --git a/src/camel/camel-win32.h b/src/camel/camel-win32.h
index d90605479..ebae6aba5 100644
--- a/src/camel/camel-win32.h
+++ b/src/camel/camel-win32.h
@@ -22,7 +22,7 @@
 #define CAMEL_WIN32_H
 
 /* need a way to configure and save this data, if this header is to
-   be installed.  For now, dont install it */
+   be installed.  For now, don't install it */
 
 #include "evolution-data-server-config.h"
 
diff --git a/src/camel/providers/imapx/camel-imapx-command.c b/src/camel/providers/imapx/camel-imapx-command.c
index 90beaf70b..f923c3b04 100644
--- a/src/camel/providers/imapx/camel-imapx-command.c
+++ b/src/camel/providers/imapx/camel-imapx-command.c
@@ -380,7 +380,7 @@ camel_imapx_command_addv (CamelIMAPXCommand *ic,
                        ps = p;
                        break;
 
-               case '\\':      /* only for \\ really, we dont support \n\r etc at all */
+               case '\\':      /* only for \\ really, we don't support \n\r etc at all */
                        c = *p;
                        if (c) {
                                g_warn_if_fail (c == '\\');
diff --git a/src/camel/providers/imapx/camel-imapx-server.c b/src/camel/providers/imapx/camel-imapx-server.c
index eeeaaf67a..6fedcfa0a 100644
--- a/src/camel/providers/imapx/camel-imapx-server.c
+++ b/src/camel/providers/imapx/camel-imapx-server.c
@@ -2263,7 +2263,7 @@ imapx_continuation (CamelIMAPXServer *is,
        gboolean success;
 
        /* The 'literal' pointer is like a write-lock, nothing else
-        * can write while we have it ... so we dont need any
+        * can write while we have it ... so we don't need any
         * ohter lock here.  All other writes go through
         * queue-lock */
        if (camel_imapx_server_is_in_idle (is)) {
diff --git a/src/camel/providers/imapx/camel-imapx-utils.c b/src/camel/providers/imapx/camel-imapx-utils.c
index fca9dad5a..8b0146fd0 100644
--- a/src/camel/providers/imapx/camel-imapx-utils.c
+++ b/src/camel/providers/imapx/camel-imapx-utils.c
@@ -1323,7 +1323,7 @@ imapx_parse_envelope (CamelIMAPXInputStream *stream,
                camel_header_address_list_clear (&addr_from);
        }
 
-       /* we dont keep reply_to */
+       /* we don't keep reply_to */
 
        /* env_reply_to    ::= "(" 1*address ")" / nil */
        addr = imapx_parse_address_list (stream, cancellable, &local_error);
@@ -1356,7 +1356,7 @@ imapx_parse_envelope (CamelIMAPXInputStream *stream,
        if (local_error)
                goto error;
 
-       /* we dont keep bcc either */
+       /* we don't keep bcc either */
 
        /* env_bcc         ::= "(" 1*address ")" / nil */
        addr = imapx_parse_address_list (stream, cancellable, &local_error);
@@ -1702,7 +1702,7 @@ imapx_parse_section (CamelIMAPXInputStream *stream,
        /* header_list     ::= "(" 1#header_fld_name ")"
         * header_fld_name ::= astring */
 
-       /* we dont need the header specifiers */
+       /* we don't need the header specifiers */
        tok = camel_imapx_input_stream_token (
                stream, &token, &len, cancellable, NULL);
 
@@ -2700,7 +2700,7 @@ imapx_parse_status (CamelIMAPXInputStream *stream,
                if (!success)
                        goto fail;
 
-               /* ignore anything we dont know about */
+               /* ignore anything we don't know about */
                do {
                        tok = camel_imapx_input_stream_token (
                                stream, &token, &len, cancellable, NULL);
diff --git a/src/camel/providers/local/camel-local-folder.c b/src/camel/providers/local/camel-local-folder.c
index e1283e159..705c0a04b 100644
--- a/src/camel/providers/local/camel-local-folder.c
+++ b/src/camel/providers/local/camel-local-folder.c
@@ -632,7 +632,7 @@ camel_local_folder_construct (CamelLocalFolder *lf,
                        /* yes, this isn't fatal at all */
                        g_warning ("Could not open/create index file: %s: indexing not performed", g_strerror 
(errno));
                        forceindex = FALSE;
-                       /* record that we dont have an index afterall */
+                       /* record that we don't have an index afterall */
                        lf->flags &= ~CAMEL_STORE_FOLDER_BODY_INDEX;
                }
        } else {
diff --git a/src/camel/providers/local/camel-local-private.h b/src/camel/providers/local/camel-local-private.h
index 0405686f3..5f747b032 100644
--- a/src/camel/providers/local/camel-local-private.h
+++ b/src/camel/providers/local/camel-local-private.h
@@ -21,7 +21,7 @@
 #define CAMEL_LOCAL_PRIVATE_H
 
 /* need a way to configure and save this data, if this header is to
- * be installed.  For now, dont install it */
+ * be installed.  For now, don't install it */
 
 #include "evolution-data-server-config.h"
 
diff --git a/src/camel/providers/local/camel-local-summary.c b/src/camel/providers/local/camel-local-summary.c
index 60d0ba1a2..65679d11a 100644
--- a/src/camel/providers/local/camel-local-summary.c
+++ b/src/camel/providers/local/camel-local-summary.c
@@ -274,7 +274,7 @@ do_stat_mi (CamelLocalSummary *cls,
                info->msgcount += mi->references->size;
        }
 
-       /* dont have any user flags yet */
+       /* don't have any user flags yet */
 
        if (mi->content) {
                do_stat_ci (cls, info, mi->content);
@@ -697,7 +697,7 @@ summary_header_load (CamelFolderSummary *s,
        CamelLocalSummary *cls = (CamelLocalSummary *) s;
        gchar *part, *tmp;
 
-       /* We dont actually add our own headers, but version that we don't anyway */
+       /* We don't actually add our own headers, but version that we don't anyway */
 
        if (!CAMEL_FOLDER_SUMMARY_CLASS (camel_local_summary_parent_class)->summary_header_load (s, fir))
                return FALSE;
diff --git a/src/camel/providers/local/camel-maildir-summary.c 
b/src/camel/providers/local/camel-maildir-summary.c
index a7749eb11..599592c4a 100644
--- a/src/camel/providers/local/camel-maildir-summary.c
+++ b/src/camel/providers/local/camel-maildir-summary.c
@@ -306,7 +306,7 @@ camel_maildir_summary_name_to_info (CamelMessageInfo *info,
        return FALSE;
 }
 
-/* for maildir, x-evolution isn't used, so dont try and get anything out of it */
+/* for maildir, x-evolution isn't used, so don't try and get anything out of it */
 static gint maildir_summary_decode_x_evolution (CamelLocalSummary *cls, const gchar *xev, CamelMessageInfo 
*mi)
 {
        return -1;
@@ -396,7 +396,7 @@ message_info_new_from_headers (CamelFolderSummary *summary,
                        camel_maildir_summary_name_to_info (mi, mds->priv->current_file);
 
 #if 0
-                       /* Actually, I dont think all this effort is worth it at all ... */
+                       /* Actually, I don't think all this effort is worth it at all ... */
 
                        /* also, see if we can extract the next-id from tne name, and safe-if-fy ourselves 
against collisions */
                        /* we check for something.something_number.something */
@@ -460,7 +460,7 @@ maildir_summary_next_uid_string (CamelFolderSummary *s)
                        retry++;
                } while (g_stat (name, &st) == 0 && retry < 3);
 
-               /* I dont know what we're supposed to do if it fails to find a unique name?? */
+               /* I don't know what we're supposed to do if it fails to find a unique name?? */
 
                g_free (name);
                return uid;
@@ -911,7 +911,7 @@ maildir_summary_sync (CamelLocalSummary *cls,
                                        g_warning ("%s: Failed to rename '%s' to '%s': %s", G_STRFUNC, name, 
dest, g_strerror (errno));
                                }
                                if (g_stat (dest, &st) == -1) {
-                                       /* we'll assume it didn't work, but dont change anything else */
+                                       /* we'll assume it didn't work, but don't change anything else */
                                } else {
                                        /* TODO: If this is made mt-safe, then this code could be a problem, 
since
                                         * the estrv is being modified.
diff --git a/src/camel/providers/local/camel-mbox-folder.c b/src/camel/providers/local/camel-mbox-folder.c
index 3300f8997..053e74d69 100644
--- a/src/camel/providers/local/camel-mbox-folder.c
+++ b/src/camel/providers/local/camel-mbox-folder.c
@@ -171,7 +171,7 @@ mbox_folder_append_message_sync (CamelFolder *folder,
 
        camel_local_folder_lock_changes (lf);
 
-       /* If we can't lock, dont do anything */
+       /* If we can't lock, don't do anything */
        if (camel_local_folder_lock (lf, CAMEL_LOCK_WRITE, error) == -1) {
                camel_local_folder_unlock_changes (lf);
                return FALSE;
@@ -357,7 +357,7 @@ retry:
 
        /* we use an fd instead of a normal stream here - the reason is subtle, camel_mime_part will cache
         * the whole message in memory if the stream is non-seekable (which it is when built from a parser
-        * with no stream).  This means we dont have to lock the mbox for the life of the message, but only
+        * with no stream).  This means we don't have to lock the mbox for the life of the message, but only
         * while it is being created. */
 
        fd = g_open (lf->folder_path, O_LARGEFILE | O_RDONLY | O_BINARY, 0);
diff --git a/src/camel/providers/local/camel-mbox-summary.c b/src/camel/providers/local/camel-mbox-summary.c
index f637e179e..2eb59dafd 100644
--- a/src/camel/providers/local/camel-mbox-summary.c
+++ b/src/camel/providers/local/camel-mbox-summary.c
@@ -821,7 +821,7 @@ mbox_summary_sync_quick (CamelMboxSummary *mbs,
 
                xev = camel_mime_parser_header (mp, "X-Evolution", &xevoffset);
                if (xev == NULL || camel_local_summary_decode_x_evolution (cls, xev, NULL) == -1) {
-                       g_warning ("We're supposed to have a valid x-ev header, but we dont");
+                       g_warning ("We're supposed to have a valid x-ev header, but we don't");
                        goto error;
                }
                xevnew = camel_local_summary_encode_x_evolution (cls, info);
diff --git a/src/camel/providers/local/camel-mh-store.c b/src/camel/providers/local/camel-mh-store.c
index c75d5096b..5b2a372e9 100644
--- a/src/camel/providers/local/camel-mh-store.c
+++ b/src/camel/providers/local/camel-mh-store.c
@@ -609,7 +609,7 @@ mh_store_get_folder_info_sync (CamelStore *store,
                        path, top, flags, cancellable);
 
                /* If we actually scanned from root,
-                * we have a "" root node we dont want. */
+                * we have a "" root node we don't want. */
                if (fi != NULL && top[0] == 0) {
                        CamelFolderInfo *rfi;
 
diff --git a/src/camel/providers/local/camel-spool-summary.c b/src/camel/providers/local/camel-spool-summary.c
index 7ffb098c0..38e77bed0 100644
--- a/src/camel/providers/local/camel-spool-summary.c
+++ b/src/camel/providers/local/camel-spool-summary.c
@@ -256,7 +256,7 @@ spool_summary_sync_full (CamelMboxSummary *cls,
                                "Folder may be corrupt, copy saved in “%s”"),
                                ((CamelLocalSummary *) cls)->folder_path,
                                g_strerror (errno), tmpname);
-                       /* so we dont delete it */
+                       /* so we don't delete it */
                        tmpname[0] = '\0';
                        g_free (buffer);
                        goto error;
diff --git a/src/camel/providers/nntp/camel-nntp-private.h b/src/camel/providers/nntp/camel-nntp-private.h
index e1df345e0..82839df70 100644
--- a/src/camel/providers/nntp/camel-nntp-private.h
+++ b/src/camel/providers/nntp/camel-nntp-private.h
@@ -22,7 +22,7 @@
 #define CAMEL_NNTP_PRIVATE_H
 
 /* need a way to configure and save this data, if this header is to
- * be installed.  For now, dont install it */
+ * be installed.  For now, don't install it */
 
 #include "evolution-data-server-config.h"
 
diff --git a/src/camel/providers/nntp/camel-nntp-store.c b/src/camel/providers/nntp/camel-nntp-store.c
index fb273bec5..16bb3ec36 100644
--- a/src/camel/providers/nntp/camel-nntp-store.c
+++ b/src/camel/providers/nntp/camel-nntp-store.c
@@ -1208,7 +1208,7 @@ nntp_store_get_folder_info_all (CamelNNTPStore *nntp_store,
                        memcpy (date + 7, nntp_store_summary->last_newslist + 8, 6); /* HHMMSS */
                        date[13] = '\0';
 
-                       /* Some servers don't support date (!), so fallback if they dont */
+                       /* Some servers don't support date (!), so fallback if they don't */
                        if (!nntp_get_date (nntp_store, cancellable, NULL))
                                goto do_complete_list_nodate;
 
diff --git a/src/camel/providers/pop3/camel-pop3-engine.h b/src/camel/providers/pop3/camel-pop3-engine.h
index 973387330..ee40c7907 100644
--- a/src/camel/providers/pop3/camel-pop3-engine.h
+++ b/src/camel/providers/pop3/camel-pop3-engine.h
@@ -70,7 +70,7 @@ typedef enum {
 
 /* flags for command types */
 enum {
-       CAMEL_POP3_COMMAND_SIMPLE = 0, /* dont expect multiline response */
+       CAMEL_POP3_COMMAND_SIMPLE = 0, /* don't expect multiline response */
        CAMEL_POP3_COMMAND_MULTI = 1 /* expect multiline response */
 };
 
@@ -126,7 +126,7 @@ struct _CamelPOP3Engine {
 
        CamelPOP3Stream *stream;
 
-       guint sentlen;  /* data sent (so we dont overflow network buffer) */
+       guint sentlen;  /* data sent (so we don't overflow network buffer) */
 
        GQueue active;  /* active commands */
        GQueue queue;   /* queue of waiting commands */
diff --git a/src/camel/providers/pop3/camel-pop3-folder.c b/src/camel/providers/pop3/camel-pop3-folder.c
index 49f69c2bb..4a3381d8e 100644
--- a/src/camel/providers/pop3/camel-pop3-folder.c
+++ b/src/camel/providers/pop3/camel-pop3-folder.c
@@ -750,7 +750,7 @@ pop3_folder_refresh_info_sync (CamelFolder *folder,
                }
        }
 
-       /* dont need this anymore */
+       /* don't need this anymore */
        g_hash_table_destroy (pop3_folder->uids_id);
        pop3_folder->uids_id = NULL;
 
@@ -1048,7 +1048,7 @@ camel_pop3_folder_new (CamelStore *parent,
        if (camel_service_get_connection_status (CAMEL_SERVICE (parent)) != CAMEL_SERVICE_CONNECTED)
                return folder;
 
-       /* mt-ok, since we dont have the folder-lock for new() */
+       /* mt-ok, since we don't have the folder-lock for new() */
        if (!camel_folder_refresh_info_sync (folder, cancellable, error)) {
                g_object_unref (folder);
                folder = NULL;
diff --git a/src/camel/providers/pop3/camel-pop3-store.c b/src/camel/providers/pop3/camel-pop3-store.c
index 818362828..8a7d2bb42 100644
--- a/src/camel/providers/pop3/camel-pop3-store.c
+++ b/src/camel/providers/pop3/camel-pop3-store.c
@@ -331,8 +331,8 @@ try_sasl (CamelPOP3Store *store,
                        break;
                }
 
-               /* If we dont get continuation, or the sasl object's run out
-                * of work, or we dont get a challenge, its a protocol error,
+               /* If we don't get continuation, or the sasl object's run out
+                * of work, or we don't get a challenge, its a protocol error,
                 * so fail, and try reset the server. */
                if (strncmp ((gchar *) line, "+ ", 2) != 0
                    || camel_sasl_get_authenticated (sasl)
@@ -438,7 +438,7 @@ pop3_store_dispose (GObject *object)
 
        priv = CAMEL_POP3_STORE (object)->priv;
 
-       /* Force disconnect so we dont have it run
+       /* Force disconnect so we don't have it run
         * later, after we've cleaned up some stuff. */
        camel_service_disconnect_sync (
                CAMEL_SERVICE (object), TRUE, NULL, NULL);
diff --git a/src/camel/tests/lib/folders.c b/src/camel/tests/lib/folders.c
index a2edadbef..f0b93411f 100644
--- a/src/camel/tests/lib/folders.c
+++ b/src/camel/tests/lib/folders.c
@@ -440,7 +440,7 @@ test_folder_message_ops (CamelSession *session,
                        }
 #endif
                        /*if (!local)
-                         camel_test_nonfatal ("unread counts dont seem right for imap");*/
+                         camel_test_nonfatal ("unread counts don't seem right for imap");*/
 
                        test_folder_counts (folder, j + 1, j + 1);
 
diff --git a/src/camel/tests/message/test2.c b/src/camel/tests/message/test2.c
index f00e23a73..fc002ea01 100644
--- a/src/camel/tests/message/test2.c
+++ b/src/camel/tests/message/test2.c
@@ -180,7 +180,7 @@ gint main (gint argc, gchar **argv)
        check (camel_internet_address_find_name (addr, "  Zed ", &where) == 0);
        check (camel_internet_address_find_name (addr, "Zed 20", &where) == -1);
        check (camel_internet_address_find_name (addr, "", &where) == -1);
-       /* interface dont handle nulls :) */
+       /* interface don't handle nulls :) */
        /*check(camel_internet_address_find_name(addr, NULL, &where) == -1);*/
 
        check (camel_internet_address_find_address (addr, "nowhere here-1 com au", &where) == 1);
diff --git a/src/examples/cursor/cursor-data.c b/src/examples/cursor/cursor-data.c
index 9d19b5805..91e02c12c 100644
--- a/src/examples/cursor/cursor-data.c
+++ b/src/examples/cursor/cursor-data.c
@@ -153,7 +153,7 @@ get_cursor (EBookClient *book_client)
 }
 
 /* Entry point for this file, here we take care of
- * creating the addressbook if it doesnt exist,
+ * creating the addressbook if it doesn't exist,
  * getting an EBookClient, and creating our EBookClientCursor.
  */
 EBookClient *
diff --git a/src/libedataserver/e-sexp.c b/src/libedataserver/e-sexp.c
index dd456ec75..3adc85196 100644
--- a/src/libedataserver/e-sexp.c
+++ b/src/libedataserver/e-sexp.c
@@ -101,7 +101,7 @@ struct _ESExpPrivate {
        gchar *error;
        GSList *operators;
 
-       /* TODO: may also need a pool allocator for term strings, so we dont lose them
+       /* TODO: may also need a pool allocator for term strings, so we don't lose them
         * in error conditions? */
        struct _EMemChunk *term_chunks;
        struct _EMemChunk *result_chunks;
diff --git a/src/private/org.gnome.evolution.dataserver.AddressBookCursor.xml 
b/src/private/org.gnome.evolution.dataserver.AddressBookCursor.xml
index ad60cc478..6ce474d12 100644
--- a/src/private/org.gnome.evolution.dataserver.AddressBookCursor.xml
+++ b/src/private/org.gnome.evolution.dataserver.AddressBookCursor.xml
@@ -64,7 +64,7 @@
       Sets the cursor's alphabetic index, the index must be valid for @locale
       and @locale is expected to be the current locale of the addressbook.
 
-      If the addressbook's locale has changed and doesnt match the @locale
+      If the addressbook's locale has changed and doesn't match the @locale
       argument then an error will be returned and the call should be retried.
 
       This will also result in changes of the Position and Total properties
diff --git a/tests/libebook/client/test-book-client-cursor-operations.c 
b/tests/libebook/client/test-book-client-cursor-operations.c
index f73ecf049..352c351d5 100644
--- a/tests/libebook/client/test-book-client-cursor-operations.c
+++ b/tests/libebook/client/test-book-client-cursor-operations.c
@@ -2667,7 +2667,7 @@ main (gint argc,
                cursor_closure_alphabet (closure, FALSE, "あ", "か", "さ", "た", "な");
                cursor_closure_add (closure, "/EBookClientCursor/ChangeLocale/Alphabet/ja_JP%s", 
base_params[i].base_path);
 
-               /* The alphabet doesnt change for chinese */
+               /* The alphabet doesn't change for chinese */
                closure = cursor_closure_new (&base_params[i], "POSIX");
                cursor_closure_alphabet (closure, TRUE, "A", "B", "C", "D", "E");
                cursor_closure_change_locale (closure, "zh_CN.utf8");
diff --git a/tests/libedataserver/e-collator-test.c b/tests/libedataserver/e-collator-test.c
index 0f895574c..fbc8e0298 100644
--- a/tests/libedataserver/e-collator-test.c
+++ b/tests/libedataserver/e-collator-test.c
@@ -129,7 +129,7 @@ test_el_GR (CollatorFixture *fixture,
   /* 'Τ' is the 19th letter */
   g_assert_cmpint (e_collator_get_index (fixture->collator, "Τρίτη"), ==, 19);
 
-  /* Texas doesnt start with 'T' ! --> Underflow */
+  /* Texas doesn't start with 'T' ! --> Underflow */
   g_assert_cmpint (e_collator_get_index (fixture->collator, "Texas"), ==, 0);
 }
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/camel/camel-folder-summary.c b/src/camel/camel-folder-summary.c
index 709fa23e8..013b0b9d9 100644
--- a/src/camel/camel-folder-summary.c
+++ b/src/camel/camel-folder-summary.c
@@ -2047,7 +2047,7 @@ save_to_db_cb (gpointer key,
 
        /* Reset the dirty flag which decides if the changes are synced to the DB or not.
        The FOLDER_FLAGGED should be used to check if the changes are synced to the server.
-       So, dont unset the FOLDER_FLAGGED flag */
+       So, don't unset the FOLDER_FLAGGED flag */
        camel_message_info_set_dirty (mi, FALSE);
 
        camel_db_camel_mir_free (mir);
@@ -2535,7 +2535,7 @@ camel_folder_summary_info_new_from_parser (CamelFolderSummary *summary,
                        camel_mime_filter_index_set_name (CAMEL_MIME_FILTER_INDEX 
(summary->priv->filter_index), name);
                }
 
                /* always scan the content info, even if we dont save it */
                summary_traverse_content_with_parser (summary, info, mp);
 
                if (name && summary->priv->index) {
@@ -2535,7 +2535,7 @@ camel_folder_summary_info_new_from_parser (CamelFolderSummary *summary,
                }
 
-               /* always scan the content info, even if we dont save it */
+               /* always scan the content info, even if we don't save it */
                summary_traverse_content_with_parser (summary, info, mp);
 